@@ -31,7 +31,9 @@ def get_diffs(text1, text2, optimized):
     return diffs
 
 
-def to_yaml(list_,):
+def to_yaml(
+    list_,
+):
     """Dump list to yaml and write the yaml to a file on mentioned path.
 
     Args:
